__title__ = "auto_media_platform"
__description__ = "generate video and upload to multiple media platform automatically"
__url__ = ""
__version__ = "0.0.2"
__author__ = "idlewith"
__author_email__ = "newellzhou@163.com"
__license__ = "MIT"
__copyright__ = "Copyright 2023 idlewith"
